@@ -48,16 +48,16 @@ def test_SEIR():
 def test_SEQIAHR():
     model = SEQIAHR()
     model([.99, 0, 1e-6, 0, 0, 0, 0, 0], [0, 300], 1, {'chi': .7, 'phi': .01, 'beta': .5,
-                                                    'rho': .05, 'delta': .1, 'alpha': .33, 'mu': .03,
-                                                    'p': .75, 'q': 50, 'r': 40
-                                                    })
+                                                       'rho': .05, 'delta': .1, 'gamma': .1,
+                                                       'alpha': .33, 'mu': .03,
+                                                       'p': .75, 'q': 50, 'r': 40
+                                                       })
     # print(model.traces)
     assert len(model.traces) == 9  # state variables plus time
     # assert len(model.traces['time']) == 50
     model.plot_traces()
     P.show()
 
-
 # def test_SIS_with_cache():
 #     model = SIS()
 #     model([1000, 1], [0, 50], 1001, {'beta': 2, 'gamma': .1})
